@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-conf.c,v 1.12 2008/09/26 10:07:43 bowkenken Exp $
+* $Id: gf-conf.c,v 1.17 2009/05/12 01:30:40 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -380,6 +380,12 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "attribute_bold" ) == 0 ){
 		return load_game_conf_attribute_bold( id, val );
 
+	} else if( strcmp( id, "gnome" ) == 0 ){
+		return load_game_conf_gnome( id, val );
+
+	} else if( strcmp( id, "set_window_position" ) == 0 ){
+		return load_game_conf_set_window_position( id, val );
+
 	}
 
 	for( i = WIN_KIND_NULL + 1; i < WIN_KIND_MAX_N; i++ ){
@@ -709,6 +715,34 @@ bool_t	load_game_conf_joystick_number( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* ե GNOME 
+* char *id : ̻
+* long val : ɸޤϥ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_gnome( char *id, long val )
+{
+	g_flg_gnome = val;
+
+	return TRUE;
+}
+
+/***************************************************************
+* եΥɥ֤򤹤뤫?
+* char *id : ̻
+* long val : ɸޤϥ
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_set_window_position( char *id, long val )
+{
+	g_flg_set_win_pos = val;
+
+	return TRUE;
+}
+
 /***************************************************************
 * եΥɥ֤
 * char *id : ̻
@@ -882,6 +916,14 @@ bool_t	load_game_conf_color_name( char *id, char *name )
 		g_crnt_attr_n = CURS_ATTR_N_MBR_5;
 	if( strcmp( name, "mbr_6" ) == 0 )
 		g_crnt_attr_n = CURS_ATTR_N_MBR_6;
+	if( strcmp( name, "heat" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_HEAT;
+	if( strcmp( name, "cold" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_COLD;
+	if( strcmp( name, "mind" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_MIND;
+	if( strcmp( name, "acid" ) == 0 )
+		g_crnt_attr_n = CURS_ATTR_N_ACID;
 
 	return TRUE;
 }
@@ -1603,6 +1645,8 @@ bool_t	save_game_conf_contents( FILE *fp, const ver_t *ver )
 	flg_err |= !save_game_conf_screen_size( fp, ver );
 	flg_err |= !save_game_conf_scroll( fp, ver );
 	flg_err |= !save_game_conf_flg( fp, ver );
+	flg_err |= !save_game_conf_gnome( fp, ver );
+	flg_err |= !save_game_conf_set_window_position( fp, ver );
 	flg_err |= !save_game_conf_win_pos( fp, ver );
 	flg_err |= !save_game_conf_joystick( fp, ver );
 	flg_err |= !save_game_conf_vfx( fp, ver );
@@ -1767,6 +1811,40 @@ bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver )
 	return TRUE;
 }
 
+/***************************************************************
+* եΥɥ֤ե饰Υ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_gnome( FILE *fp, const ver_t *ver )
+{
+	fprintf( fp, "\n" );
+	fprintf( fp, "# window manager is GNOME\n" );
+	fprintf( fp, "gnome = %ld\n",
+			(long)g_flg_gnome );
+
+	return TRUE;
+}
+
+/***************************************************************
+* եΥɥ֤ե饰Υ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_set_window_position( FILE *fp, const ver_t *ver )
+{
+	fprintf( fp, "\n" );
+	fprintf( fp, "# set window position\n" );
+	fprintf( fp, "set_window_position = %ld\n",
+			(long)g_flg_set_win_pos );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եΥɥ֤Υ
 * FILE *fp : ե
@@ -1830,7 +1908,7 @@ bool_t	save_game_conf_joystick( FILE *fp, const ver_t *ver )
 	fprintf( fp, "\n" );
 
 	n = call_game_joystick_get_joy();
-	kind = call_game_joystick_get_kind();
+	kind = (joy_kind_t)call_game_joystick_get_kind();
 	name = cv_joystick_kind_to_name( kind );
 
 	fprintf( fp, "joystick_number = %ld\n", (long)n );
@@ -1959,6 +2037,14 @@ bool_t	save_game_conf_color( FILE *fp, const ver_t *ver )
 			CURS_ATTR_N_MBR_5 );
 	save_game_conf_color_sub( fp, "mbr_6",
 			CURS_ATTR_N_MBR_6 );
+	save_game_conf_color_sub( fp, "heat",
+			CURS_ATTR_N_HEAT );
+	save_game_conf_color_sub( fp, "cold",
+			CURS_ATTR_N_COLD );
+	save_game_conf_color_sub( fp, "mind",
+			CURS_ATTR_N_MIND );
+	save_game_conf_color_sub( fp, "acid",
+			CURS_ATTR_N_ACID );
 
 	return TRUE;
 }
@@ -2241,6 +2327,8 @@ const char	*get_win_kind_name( win_kind_t k )
 		return "window_replay";
 	case WIN_KIND_CLASS_EDIT:
 		return "window_class_edit";
+	case WIN_KIND_SKILL_EDIT:
+		return "window_skill_edit";
 	case WIN_KIND_CHR_SHEET:
 		return "window_character_sheet";
 	case WIN_KIND_MAX_N:
