@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.63 2008/09/07 11:31:27 bowkenken Exp $
+* $Id: gmain.h,v 1.67 2009/05/12 01:30:40 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -148,6 +148,21 @@ EXTERN bool_t	g_flg_cui;
 /* GUI ⡼ */
 EXTERN bool_t	g_flg_gui;
 
+/* ɥɸ򥪥ץǻꤵ줿? */
+EXTERN bool_t	g_flg_win_pos_arg_overwrite;
+
+/* ɥޥ͡㤬 GNOME 򥪥ץǻꤵ줿? */
+EXTERN bool_t	g_flg_gnome_arg;
+
+/* ɥޥ͡㤬 GNOME ? */
+EXTERN bool_t	g_flg_gnome;
+
+/* ɥɽ˰֤ꤹ뤫򥪥ץǻꤵ줿? */
+EXTERN bool_t	g_flg_set_win_pos_arg;
+
+/* ɥɽ˰֤ꤹ뤫? */
+EXTERN bool_t	g_flg_set_win_pos;
+
 /* GUI Υƥɽ⡼ */
 EXTERN bool_t	g_flg_text_mode;
 
