@@ -6,10 +6,14 @@ extern "C" {
 
 void	init_var_main_menu( void );
 void	init_main_menu( void );
+void	reset_static_main_menu( void );
 char	*exec_menu_sel_mbr(
-	mbr_t **mbr, char *ttl, bool_t flg_sel_dead, bool_t flg_sel_pet
+	mbr_t **mbr, char *ttl,
+	bool_t flg_sel_dead, bool_t flg_sel_pet
 );
 char	*cb_menu_sel_mbr( menu_t **pp, menu_t **dflt );
+char	*exec_menu_sel_abl( mbr_t *mbr, abl_kind_t *abl );
+char	*cb_menu_sel_abl( menu_t **pp, menu_t **dflt );
 char	*exec_menu_point_crsr( void );
 char	*exec_menu_race( race_t *race );
 char	*cb_menu_main_race( menu_t **pp, menu_t **dflt );
@@ -83,6 +87,7 @@ char	*cb_menu_item_ready_throw( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_send( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt );
+char	*cb_menu_item_alias( menu_t **pp, menu_t **dflt );
 char	*cb_menu_item_chk( menu_t **pp, menu_t **dflt );
 char	*cb_menu_goto_equip( menu_t **pp, menu_t **dflt );
 long	get_equip_ttl_max_len( void );
@@ -101,16 +106,21 @@ char	*menu_equip_take_off( menu_t **pp, menu_t **dflt );
 char	*cb_menu_goto_item( menu_t **pp, menu_t **dflt );
 char	*cb_menu_move( menu_t **pp, menu_t **dflt );
 char	*cb_menu_fight( menu_t **pp, menu_t **dflt );
-char	*cb_menu_load( menu_t **pp, menu_t **dflt );
-char	*cb_menu_save( menu_t **pp, menu_t **dflt );
-bool_t	menu_load( bool_t flg_txt );
+char	*cb_menu_load_wiz( menu_t **pp, menu_t **dflt );
+char	*cb_menu_save_wiz( menu_t **pp, menu_t **dflt );
+void	menu_load_wiz( void );
+void	menu_save_wiz( void );
+bool_t	menu_load( bool_t flg_txt, bool_t flg_new_game );
 bool_t	menu_save( bool_t flg_txt );
 bool_t	menu_save_n( bool_t flg_txt, long save_n );
-long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt );
+long	menu_sel_save_load(
+	bool_t flg_save, bool_t flg_txt, bool_t flg_new_game
+);
 void	set_ttl_menu_save_load(
 	menu_t *ls, bool_t flg_save, bool_t flg_txt
 );
 char	*cb_menu_save_load( menu_t **pp, menu_t **dflt );
+char	*cb_menu_new_game( menu_t **pp, menu_t **dflt );
 void	set_flg_no_save( bool_t flg );
 bool_t	get_flg_no_save( void );
 bool_t	exec_menu_identify_item( mbr_t *mbr );
