@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: nest-flg.c,v 1.7 2008/01/11 09:12:57 bowkenken Exp $
+* $Id: nest-flg.c,v 1.9 2009/01/04 00:24:52 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -40,6 +40,14 @@
 static long	g_nest_flg[NEST_FLG_MAX_N];
 static long	g_nest_flg_n;
 
+/***************************************************************
+* ƥåѿꥻå
+***************************************************************/
+
+void	reset_static_nest_flg( void )
+{
+}
+
 /***************************************************************
 * ե饰κ
 * return : ե饰ֹreturn <= -1 顼
