@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.60 2008/04/16 16:12:34 bowkenken Exp $
+* $Id: pet.c,v 1.63 2009/03/10 09:06:46 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -67,6 +67,8 @@ void	init_pet( void )
 
 	if( g_flg_debug )
 		init_pet_debug();
+	else
+		init_pet_dflt();
 }
 
 /***************************************************************
@@ -77,6 +79,25 @@ void	reset_static_pet( void )
 {
 }
 
+/***************************************************************
+* ̾ΥڥåȤν
+***************************************************************/
+
+void	init_pet_dflt( void )
+{
+	party_t	*pty = get_party();
+	pet_t	*p;
+	long	i;
+
+	i = 0;
+	p = make_pet( 10, MNSTR_KIND_PYON_PYON, pty->mbr[i] );
+	if( p == NULL )
+		return;
+
+	str_nz_cpy( p->name, "Pyon Pyon", PET_NAME_MAX_LEN );
+	join_pet( p );
+}
+
 /***************************************************************
 * ǥХåΥڥåȤν
 ***************************************************************/
@@ -89,8 +110,11 @@ void	init_pet_debug( void )
 
 	i = 0;
 	p = make_pet( 10, MNSTR_KIND_PYON_PYON, pty->mbr[i] );
-	if( p != NULL )
-		join_pet( p );
+	if( p == NULL )
+		return;
+
+	str_nz_cpy( p->name, "Pyon Pyon", PET_NAME_MAX_LEN );
+	join_pet( p );
 }
 
 /***************************************************************
