@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.100 2008/10/06 07:07:10 bowkenken Exp $
+* $Id: request.c,v 1.105 2009/04/11 11:00:51 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -111,6 +111,21 @@
 
 #define	REQUEST_PENALTY_RATE	((rate_t)10)
 
+/***************************************************************
+* 󽷤Υƥ
+***************************************************************/
+
+scroll_kind_t	ls_reward_scroll[] = {
+	SCROLL_KIND_POW_UP_WPN_HIT,
+	SCROLL_KIND_POW_UP_WPN_CRTCL,
+	SCROLL_KIND_POW_UP_WPN_DAM,
+	SCROLL_KIND_POW_UP_ARMOR_DEF,
+	SCROLL_KIND_POW_UP_ARMOR_CRTCL,
+	SCROLL_KIND_POW_UP_ARMOR_AC,
+
+	SCROLL_KIND_NULL,
+};
+
 /***************************************************************
 * Хѿ
 ***************************************************************/
@@ -181,19 +196,33 @@ request_t	*make_request_randm( void )
 	case REQUEST_KIND_NULL:
 		break;
 	case REQUEST_KIND_RARE_GOODS:
-		return make_request_rare_goods( req );
+		if( make_request_rare_goods( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_TAME_MNSTR:
-		return make_request_tame_mnstr( req );
+		if( make_request_tame_mnstr( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_RESCUE:
-		return make_request_rescue( req );
+		if( make_request_rescue( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_TOUR_GUIDE:
-		return make_request_tour_guide( req );
+		if( make_request_tour_guide( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_EXTERMINATE:
-		return make_request_exterminate( req );
+		if( make_request_exterminate( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_REVENGE:
-		return make_request_revenge( req );
+		if( make_request_revenge( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_WANTED_CRIMINAL:
-		return make_request_wanted_criminal( req );
+		if( make_request_wanted_criminal( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_MAX_N:
 		break;
 	}
@@ -455,6 +484,8 @@ request_t	*make_request_exterminate( request_t *req )
 	tab = get_mnstr_tab_rand( -dun_lev );
 	if( tab == NULL )
 		return NULL;
+	if( tab->mnstr_kind == MNSTR_KIND_NULL )
+		return NULL;
 	lev_tab = get_mnstr_lev_tab( tab->mnstr_kind, dun_lev );
 	if( lev_tab == NULL )
 		return NULL;
@@ -717,8 +748,9 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	}
 
 	if( (msg_female != NULL) && (msg_male != NULL) ){
-		print_words( words_name, words_sex,
+		print_words_win( words_name, words_sex,
 				msg_female, msg_male, npc->name );
+		redraw_all();
 	}
 	print_msg( FLG_NULL, MSG_JOIN_CHR, npc->name );
 
@@ -1073,14 +1105,14 @@ bool_t	chk_request_limit_client( request_t *req )
 	case REQUEST_KIND_TAME_MNSTR:
 		return TRUE;	/* FALSE ǤϤʤ */
 	case REQUEST_KIND_RESCUE:
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				MSG_WORDS_REQUEST_RESCUE_LIMIT_FEMALE,
 				MSG_WORDS_REQUEST_RESCUE_LIMIT_MALE,
 				npc->name );
 		flg_trans_mnstr = TRUE;
 		break;
 	case REQUEST_KIND_TOUR_GUIDE:
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				MSG_WORDS_REQUEST_TOUR_GUIDE_LIMIT_FEMALE,
 				MSG_WORDS_REQUEST_TOUR_GUIDE_LIMIT_MALE,
 				npc->name );
@@ -1089,7 +1121,7 @@ bool_t	chk_request_limit_client( request_t *req )
 	case REQUEST_KIND_EXTERMINATE:
 		return FALSE;
 	case REQUEST_KIND_REVENGE:
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				MSG_WORDS_REQUEST_REVENGE_LIMIT_FEMALE,
 				MSG_WORDS_REQUEST_REVENGE_LIMIT_MALE,
 				npc->name );
@@ -1100,6 +1132,8 @@ bool_t	chk_request_limit_client( request_t *req )
 		return FALSE;
 	}
 
+	redraw_all();
+
 	/* ̤ */
 
 	print_msg( FLG_NULL, MSG_NOT_JOIN_CHR, npc->name );
@@ -1206,9 +1240,10 @@ void	chk_set_request_npc_contract( void )
 
 bool_t	set_request_msg( request_t *req )
 {
-	char	buf[REQUEST_MSG_MAX_LEN * 2], *fmt;
+	static char	buf[REQUEST_MSG_MAX_LEN + 1];
+	static char	str_contract[REQUEST_MSG_MAX_LEN + 1];
+	char	*fmt;
 	long	buf_idx, fmt_idx;
-	char	str_contract[REQUEST_MSG_MAX_LEN + 1];
 
 	if( req == NULL )
 		return FALSE;
@@ -1380,7 +1415,8 @@ void	set_request_msg_var_dun_lev_range(
 	request_t *req, char *buf, char *arg
 )
 {
-	char	str_min[32 + 1], str_max[32 + 1];
+	static char	str_min[32 * 4 + 1], str_max[32 * 4 + 1];
+	long	max_len = 32 * 4;
 
 	if( buf == NULL )
 		return;
@@ -1389,29 +1425,29 @@ void	set_request_msg_var_dun_lev_range(
 		return;
 
 	if( req->dun_min_lev >= +1 ){
-		sn_printf( str_min, 32, MSG_FLOOR_FMT,
+		sn_printf( str_min, max_len, MSG_FLOOR_FMT,
 				labs( req->dun_min_lev ) );
 	} else if( req->dun_min_lev <= -1 ){
-		sn_printf( str_min, 32, MSG_BASE_FMT,
+		sn_printf( str_min, max_len, MSG_BASE_FMT,
 				labs( req->dun_min_lev ) );
 	} else {
-		sn_printf( str_min, 32, MSG_S, MSG_GROUND );
+		sn_printf( str_min, max_len, MSG_S, MSG_GROUND );
 	}
 
 	if( req->dun_max_lev >= +1 ){
-		sn_printf( str_max, 32, MSG_FLOOR_FMT,
+		sn_printf( str_max, max_len, MSG_FLOOR_FMT,
 				labs( req->dun_max_lev ) );
 	} else if( req->dun_max_lev <= -1 ){
-		sn_printf( str_max, 32, MSG_BASE_FMT,
+		sn_printf( str_max, max_len, MSG_BASE_FMT,
 				labs( req->dun_max_lev ) );
 	} else {
-		sn_printf( str_max, 32, MSG_S, MSG_GROUND );
+		sn_printf( str_max, max_len, MSG_S, MSG_GROUND );
 	}
 
 	if( req->dun_min_lev == req->dun_max_lev ){
-		sn_printf( buf, 32, MSG_REQUEST_DUN_LEV, str_max );
+		sn_printf( buf, max_len, MSG_REQUEST_DUN_LEV, str_max );
 	} else {
-		sn_printf( buf, 32, MSG_REQUEST_DUN_LEV_RANGE,
+		sn_printf( buf, max_len, MSG_REQUEST_DUN_LEV_RANGE,
 				str_min, str_max );
 	}
 }
@@ -1893,13 +1929,15 @@ void	chk_find_request_chr( chr_t *chr )
 		msg_fema = MSG_WORDS_REQUEST_TAME_MNSTR_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_TAME_MNSTR_FIND_MALE;
 
-		print_words( mbr->name, mbr->sex.cur, msg_fema, msg_male );
+		print_words_win( mbr->name, mbr->sex.cur,
+				msg_fema, msg_male );
 		break;
 	case REQUEST_KIND_RESCUE:
 		msg_fema = MSG_WORDS_REQUEST_RESCUE_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_RESCUE_FIND_MALE;
 
-		print_words( mbr->name, mbr->sex.cur, msg_fema, msg_male );
+		print_words_win( mbr->name, mbr->sex.cur,
+				msg_fema, msg_male );
 		break;
 	case REQUEST_KIND_TOUR_GUIDE:
 		break;
@@ -1909,7 +1947,7 @@ void	chk_find_request_chr( chr_t *chr )
 		msg_fema = MSG_WORDS_REQUEST_REVENGE_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_REVENGE_FIND_MALE;
 
-		print_words( cv_idx_to_client_name( req ),
+		print_words_win( cv_idx_to_client_name( req ),
 				req->client_sex,
 				msg_fema,
 				msg_male,
@@ -1919,7 +1957,7 @@ void	chk_find_request_chr( chr_t *chr )
 		msg_fema = MSG_WORDS_REQUEST_WANTED_CRIMINAL_FIND_FEMALE;
 		msg_male = MSG_WORDS_REQUEST_WANTED_CRIMINAL_FIND_MALE;
 
-		print_words( mbr->name, mbr->sex.cur,
+		print_words_win( mbr->name, mbr->sex.cur,
 				msg_fema,
 				msg_male,
 				cv_idx_to_mnstr_name( req ) );
@@ -1927,6 +1965,8 @@ void	chk_find_request_chr( chr_t *chr )
 	case REQUEST_KIND_MAX_N:
 		break;
 	}
+
+	redraw_all();
 }
 
 /***************************************************************
@@ -2166,9 +2206,10 @@ bool_t	chk_finish_request_revenge( request_t *req, chr_t *chr )
 	if( cmp_chr( npc, chr ) )
 		return FALSE;
 
-	print_words( npc->name, npc->sex.cur,
+	print_words_win( npc->name, npc->sex.cur,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_FEMALE,
 			MSG_WORDS_REQUEST_REVENGE_FINISH_MALE );
+	redraw_all();
 
 	finish_request( req );
 
@@ -2273,24 +2314,73 @@ bool_t	close_request( request_t *req, chr_kind_t chr_kind )
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
 
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_1_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_1_MALE );
 
 	add_party_gold( req->prize );
+	give_party_reward_item_randm();
 	exp_party( req->exp, FALSE, TRUE );
 
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CLOSE_2_FEMALE,
 			MSG_WORDS_REQUEST_CLOSE_2_MALE );
 
 	/* end */
 
+	redraw_all();
+
 	req->kind = REQUEST_KIND_NULL;
 
 	return TRUE;
 }
 
+/***************************************************************
+* ʥƥ󽷤ȤƥѡƥͿ
+***************************************************************/
+
+void	give_party_reward_item_randm()
+{
+	scroll_kind_t	kind;
+	long	n;
+	long	tab_n;
+	item_t	*item;
+	long	i;
+
+	kind = SCROLL_KIND_NULL;
+	n = 0;
+	for( i = 0; i < LOOP_MAX_1000; i++ ){
+		if( ls_reward_scroll[i] == SCROLL_KIND_NULL )
+			break;
+
+		n++;
+		if( per_randm( n ) )
+			kind = ls_reward_scroll[i];
+	}
+	if( kind == SCROLL_KIND_NULL )
+		return;
+
+	tab_n = get_scroll_tab_n( get_scroll_tab( kind ) );
+	item = make_item_scroll( -1, tab_n );
+	item->flg |= (FLG_ITEM_DETECTED | FLG_ITEM_IDENTIFIED);
+	item->flg &= ~(FLG_ITEM_CURSED);
+	set_item_name( item );
+
+	if( !give_party_reward_item( item ) )
+		del_item( item );
+}
+
+/***************************************************************
+* Υƥ󽷤ȤƥѡƥͿ
+* item_t *item : ƥ
+* return : Ϳ줿?
+***************************************************************/
+
+bool_t	give_party_reward_item( item_t *item )
+{
+	return give_party_item( item, TRUE, TRUE );
+}
+
 /***************************************************************
 * طƤΰ̤
 * request_t *req : 
@@ -2364,10 +2454,12 @@ void	not_join_client( request_t *req, pet_t *npc, bool_t flg_success )
 	}
 
 	if( flg_success && (msg_female != NULL) && (msg_male != NULL) ){
-		print_words( npc->name, npc->sex.cur,
+		print_words_win( npc->name, npc->sex.cur,
 				msg_female, msg_male );
 	}
 
+	redraw_all();
+
 	print_msg( FLG_NULL, MSG_NOT_JOIN_CHR, npc->name );
 	npc->gold = 0;
 	remove_pet( npc );
@@ -2825,7 +2917,7 @@ bool_t	ask_contract_request( request_t *req )
 
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CONTRACT_FEMALE,
 			MSG_WORDS_REQUEST_CONTRACT_MALE );
 
@@ -2869,7 +2961,7 @@ bool_t	ask_cancel_request( request_t *req )
 
 	master_sex = get_npc_sex_shop( SHOP_N_BAR );
 	master_name = get_npc_name_shop( SHOP_N_BAR, master_sex );
-	print_words( master_name, master_sex,
+	print_words_win( master_name, master_sex,
 			MSG_WORDS_REQUEST_CANCEL_FEMALE,
 			MSG_WORDS_REQUEST_CANCEL_MALE );
 
